@@ -34,7 +34,7 @@
 
 static DBusConnection *connection;
 static GHashTable *session_hash;
-static connman_bool_t sessionmode;
+static bool sessionmode;
 static struct connman_session *ecall_session;
 static GSList *policy_list;
 static uint32_t session_mark = 256;
@@ -88,13 +88,13 @@ struct connman_session {
 
 	struct connman_session_policy *policy;
 
-	connman_bool_t append_all;
+	bool append_all;
 	struct session_info *info;
 	struct session_info *info_last;
 	struct connman_session_config *policy_config;
 	GSList *user_allowed_bearers;
 
-	connman_bool_t ecall;
+	bool ecall;
 
 	enum connman_session_id_type id_type;
 	struct firewall_context *fw;
@@ -276,7 +276,7 @@ err:
 
 static void cleanup_firewall(void)
 {
-	if (global_firewall == NULL)
+	if (!global_firewall)
 		return;
 
 	__connman_firewall_disable(global_firewall);
@@ -294,7 +294,7 @@ static int init_firewall_session(struct connman_session *session)
 	DBG("");
 
 	fw = __connman_firewall_create();
-	if (fw == NULL)
+	if (!fw)
 		return -ENOMEM;
 
 	switch (session->policy_config->id_type) {
@@ -350,7 +350,7 @@ err:
 
 static void cleanup_firewall_session(struct connman_session *session)
 {
-	if (session->fw == NULL)
+	if (!session->fw)
 		return;
 
 	__connman_firewall_disable(session->fw);
@@ -384,7 +384,7 @@ static int init_routing_table(struct connman_session *session)
 
 static void del_default_route(struct connman_session *session)
 {
-	if (session->gateway != NULL)
+	if (!session->gateway)
 		return;
 
 	DBG("index %d routing table %d default gateway %s",
@@ -403,7 +403,7 @@ static void add_default_route(struct connman_session *session)
 	struct connman_ipconfig *ipconfig;
 	int err;
 
-	if (info->entry == NULL)
+	if (!info->entry)
 		return;
 
 	ipconfig = __connman_service_get_ip4config(info->entry->service);
@@ -440,7 +440,7 @@ static void update_routing_table(struct connman_session *session)
 
 static void destroy_policy_config(struct connman_session *session)
 {
-	if (session->policy == NULL) {
+	if (!session->policy) {
 		g_free(session->policy_config);
 		return;
 	}
@@ -450,7 +450,7 @@ static void destroy_policy_config(struct connman_session *session)
 
 static void free_session(struct connman_session *session)
 {
-	if (session == NULL)
+	if (!session)
 		return;
 
 	if (session->notify_watch > 0)
@@ -475,11 +475,11 @@ static void cleanup_session_final(struct connman_session *session)
 	DBG("remove %s", session->session_path);
 
 	g_slist_free(session->user_allowed_bearers);
-	if (session->service_hash != NULL)
+	if (session->service_hash)
 		g_hash_table_destroy(session->service_hash);
 	g_list_free(session->service_list);
 
-	if (info->entry != NULL &&
+	if (info->entry &&
 			info->entry->reason == CONNMAN_SESSION_REASON_CONNECT) {
 		__connman_service_disconnect(info->entry->service);
 	}
@@ -508,7 +508,7 @@ static void cleanup_session(gpointer user_data)
 	cleanup_routing_table(session);
 	cleanup_firewall_session(session);
 
-	if (session->nfctx != NULL)
+	if (session->nfctx)
 		__connman_nfacct_disable(session->nfctx, nfacct_cleanup_cb,
 						session);
 	else
@@ -517,10 +517,10 @@ static void cleanup_session(gpointer user_data)
 
 static int assign_policy_plugin(struct connman_session *session)
 {
-	if (session->policy != NULL)
+	if (session->policy)
 		return -EALREADY;
 
-	if (policy_list == NULL)
+	if (!policy_list)
 		return 0;
 
 	session->policy = policy_list->data;
@@ -539,10 +539,10 @@ struct creation_data {
 
 static void cleanup_creation_data(struct creation_data *creation_data)
 {
-	if (creation_data == NULL)
+	if (!creation_data)
 		return;
 
-	if (creation_data->pending != NULL)
+	if (creation_data->pending)
 		dbus_message_unref(creation_data->pending);
 
 	g_slist_free(creation_data->allowed_bearers);
@@ -555,9 +555,9 @@ static int create_policy_config(struct connman_session *session,
 {
 	struct connman_session_config *config;
 
-	if (session->policy == NULL) {
+	if (!session->policy) {
 		config = connman_session_create_default_config();
-		if (config == NULL) {
+		if (!config) {
 			free_session(session);
 			cleanup_creation_data(creation_data);
 			return -ENOMEM;
@@ -580,10 +580,10 @@ static void probe_policy(struct connman_session_policy *policy)
 
 	g_hash_table_iter_init(&iter, session_hash);
 
-	while (g_hash_table_iter_next(&iter, &key, &value) == TRUE) {
+	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		session = value;
 
-		if (session->policy != NULL)
+		if (session->policy)
 			continue;
 
 		assign_policy_plugin(session);
@@ -596,14 +596,14 @@ static void remove_policy(struct connman_session_policy *policy)
 	gpointer key, value;
 	struct connman_session *session;
 
-	if (session_hash == NULL)
+	if (!session_hash)
 		return;
 
 	DBG("policy %p name %s", policy, policy->name);
 
 	g_hash_table_iter_init(&iter, session_hash);
 
-	while (g_hash_table_iter_next(&iter, &key, &value) == TRUE) {
+	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		session = value;
 
 		if (session->policy != policy)
@@ -627,7 +627,7 @@ int connman_session_policy_register(struct connman_session_policy *policy)
 {
 	DBG("name %s", policy->name);
 
-	if (policy->create == NULL || policy->destroy == NULL)
+	if (!policy->create || !policy->destroy)
 		return -EINVAL;
 
 	policy_list = g_slist_insert_sorted(policy_list, policy,
@@ -747,10 +747,10 @@ static int filter_bearer(GSList *policy_bearers,
 	enum connman_service_type policy;
 	GSList *it;
 
-	if (policy_bearers == NULL)
+	if (!policy_bearers)
 		return 0;
 
-	for (it = policy_bearers; it != NULL; it = it->next) {
+	for (it = policy_bearers; it; it = it->next) {
 		policy = GPOINTER_TO_INT(it->data);
 
 		if (bearer == CONNMAN_SERVICE_TYPE_UNKNOWN) {
@@ -783,7 +783,7 @@ static int apply_policy_on_bearers(GSList *policy_bearers, GSList *bearers,
 
 	*list = NULL;
 
-	for (it = bearers; it != NULL; it = it->next) {
+	for (it = bearers; it; it = it->next) {
 		bearer = GPOINTER_TO_INT(it->data);
 
 		err = filter_bearer(policy_bearers, bearer, list);
@@ -805,11 +805,11 @@ static void append_allowed_bearers(DBusMessageIter *iter, void *user_data)
 	GSList *list;
 
 	for (list = info->config.allowed_bearers;
-			list != NULL; list = list->next) {
+			list; list = list->next) {
 		enum connman_service_type bearer = GPOINTER_TO_INT(list->data);
 		const char *name = __connman_service_type2string(bearer);
 
-		if (name == NULL)
+		if (!name)
 			name = "*";
 
 		dbus_message_iter_append_basic(iter, DBUS_TYPE_STRING,
@@ -822,16 +822,15 @@ static void append_ipconfig_ipv4(DBusMessageIter *iter, void *user_data)
 	struct connman_service *service = user_data;
 	struct connman_ipconfig *ipconfig_ipv4;
 
-	if (service == NULL)
+	if (!service)
 		return;
 
-	if (__connman_service_is_connected_state(service,
-				CONNMAN_IPCONFIG_TYPE_IPV4) == FALSE) {
+	if (!__connman_service_is_connected_state(service,
+						CONNMAN_IPCONFIG_TYPE_IPV4))
 		return;
-	}
 
 	ipconfig_ipv4 = __connman_service_get_ip4config(service);
-	if (ipconfig_ipv4 == NULL)
+	if (!ipconfig_ipv4)
 		return;
 
 	__connman_ipconfig_append_ipv4(ipconfig_ipv4, iter);
@@ -842,17 +841,16 @@ static void append_ipconfig_ipv6(DBusMessageIter *iter, void *user_data)
 	struct connman_service *service = user_data;
 	struct connman_ipconfig *ipconfig_ipv4, *ipconfig_ipv6;
 
-	if (service == NULL)
+	if (!service)
 		return;
 
-	if (__connman_service_is_connected_state(service,
-				CONNMAN_IPCONFIG_TYPE_IPV6) == FALSE) {
+	if (!__connman_service_is_connected_state(service,
+						CONNMAN_IPCONFIG_TYPE_IPV6))
 		return;
-	}
 
 	ipconfig_ipv4 = __connman_service_get_ip4config(service);
 	ipconfig_ipv6 = __connman_service_get_ip6config(service);
-	if (ipconfig_ipv6 == NULL)
+	if (!ipconfig_ipv6)
 		return;
 
 	__connman_ipconfig_append_ipv6(ipconfig_ipv6, iter, ipconfig_ipv4);
@@ -866,7 +864,7 @@ static void append_notify(DBusMessageIter *dict,
 	struct connman_service *service;
 	const char *name, *ifname, *bearer;
 
-	if (session->append_all == TRUE ||
+	if (session->append_all ||
 			info->state != info_last->state) {
 		const char *state = state2string(info->state);
 
@@ -876,9 +874,9 @@ static void append_notify(DBusMessageIter *dict,
 		info_last->state = info->state;
 	}
 
-	if (session->append_all == TRUE ||
+	if (session->append_all ||
 			info->entry != info_last->entry) {
-		if (info->entry == NULL) {
+		if (!info->entry) {
 			name = "";
 			ifname = "";
 			service = NULL;
@@ -913,7 +911,7 @@ static void append_notify(DBusMessageIter *dict,
 		info_last->entry = info->entry;
 	}
 
-	if (session->append_all == TRUE ||
+	if (session->append_all ||
 			info->config.type != info_last->config.type) {
 		const char *type = type2string(info->config.type);
 
@@ -923,7 +921,7 @@ static void append_notify(DBusMessageIter *dict,
 		info_last->config.type = info->config.type;
 	}
 
-	if (session->append_all == TRUE ||
+	if (session->append_all ||
 			info->config.allowed_bearers != info_last->config.allowed_bearers) {
 		connman_dbus_dict_append_array(dict, "AllowedBearers",
 						DBUS_TYPE_STRING,
@@ -932,53 +930,53 @@ static void append_notify(DBusMessageIter *dict,
 		info_last->config.allowed_bearers = info->config.allowed_bearers;
 	}
 
-	session->append_all = FALSE;
+	session->append_all = false;
 }
 
-static connman_bool_t is_type_matching_state(enum connman_session_state *state,
+static bool is_type_matching_state(enum connman_session_state *state,
 						enum connman_session_type type)
 {
 	switch (type) {
 	case CONNMAN_SESSION_TYPE_UNKNOWN:
-		return FALSE;
+		return false;
 	case CONNMAN_SESSION_TYPE_ANY:
-		return TRUE;
+		return true;
 	case CONNMAN_SESSION_TYPE_LOCAL:
 		if (*state >= CONNMAN_SESSION_STATE_CONNECTED) {
 			*state = CONNMAN_SESSION_STATE_CONNECTED;
-			return TRUE;
+			return true;
 		}
 
 		break;
 	case CONNMAN_SESSION_TYPE_INTERNET:
 		if (*state == CONNMAN_SESSION_STATE_ONLINE)
-			return TRUE;
+			return true;
 		break;
 	}
 
-	return FALSE;
+	return false;
 }
 
-static connman_bool_t compute_notifiable_changes(struct connman_session *session)
+static bool compute_notifiable_changes(struct connman_session *session)
 {
 	struct session_info *info_last = session->info_last;
 	struct session_info *info = session->info;
 
-	if (session->append_all == TRUE)
-		return TRUE;
+	if (session->append_all)
+		return true;
 
 	if (info->state != info_last->state)
-		return TRUE;
+		return true;
 
 	if (info->entry != info_last->entry &&
 			info->state >= CONNMAN_SESSION_STATE_CONNECTED)
-		return TRUE;
+		return true;
 
 	if (info->config.allowed_bearers != info_last->config.allowed_bearers ||
 			info->config.type != info_last->config.type)
-		return TRUE;
+		return true;
 
-	return FALSE;
+	return false;
 }
 
 static gboolean session_notify(gpointer user_data)
@@ -987,7 +985,7 @@ static gboolean session_notify(gpointer user_data)
 	DBusMessage *msg;
 	DBusMessageIter array, dict;
 
-	if (compute_notifiable_changes(session) == FALSE)
+	if (!compute_notifiable_changes(session))
 		return FALSE;
 
 	DBG("session %p owner %s notify_path %s", session,
@@ -996,7 +994,7 @@ static gboolean session_notify(gpointer user_data)
 	msg = dbus_message_new_method_call(session->owner, session->notify_path,
 						CONNMAN_NOTIFICATION_INTERFACE,
 						"Update");
-	if (msg == NULL)
+	if (!msg)
 		return FALSE;
 
 	dbus_message_iter_init_append(msg, &array);
@@ -1029,35 +1027,35 @@ static void ipconfig_ipv6_changed(struct connman_session *session)
 						info->entry->service);
 }
 
-static connman_bool_t service_type_match(struct connman_session *session,
+static bool service_type_match(struct connman_session *session,
 					struct connman_service *service)
 {
 	struct session_info *info = session->info;
 	GSList *list;
 
 	for (list = info->config.allowed_bearers;
-			list != NULL; list = list->next) {
+			list; list = list->next) {
 		enum connman_service_type bearer = GPOINTER_TO_INT(list->data);
 		enum connman_service_type service_type;
 
 		if (bearer == CONNMAN_SERVICE_TYPE_UNKNOWN)
-			return TRUE;
+			return true;
 
 		service_type = connman_service_get_type(service);
 		if (bearer == service_type)
-			return TRUE;
+			return true;
 	}
 
-	return FALSE;
+	return false;
 }
 
-static connman_bool_t service_match(struct connman_session *session,
+static bool service_match(struct connman_session *session,
 					struct connman_service *service)
 {
-	if (service_type_match(session, service) == FALSE)
-		return FALSE;
+	if (!service_type_match(session, service))
+		return false;
 
-	return TRUE;
+	return true;
 }
 
 static int service_type_weight(enum connman_service_type type)
@@ -1106,7 +1104,7 @@ static gint sort_allowed_bearers(struct connman_service *service_a,
 	type_b = connman_service_get_type(service_b);
 
 	for (list = info->config.allowed_bearers;
-			list != NULL; list = list->next) {
+			list; list = list->next) {
 		enum connman_service_type bearer = GPOINTER_TO_INT(list->data);
 
 		if (bearer == CONNMAN_SERVICE_TYPE_UNKNOWN) {
@@ -1166,7 +1164,7 @@ static enum connman_session_state service_to_session_state(enum connman_service_
 	return CONNMAN_SESSION_STATE_DISCONNECTED;
 }
 
-static connman_bool_t is_connected(enum connman_service_state state)
+static bool is_connected(enum connman_service_state state)
 {
 	switch (state) {
 	case CONNMAN_SERVICE_STATE_UNKNOWN:
@@ -1178,13 +1176,13 @@ static connman_bool_t is_connected(enum connman_service_state state)
 		break;
 	case CONNMAN_SERVICE_STATE_READY:
 	case CONNMAN_SERVICE_STATE_ONLINE:
-		return TRUE;
+		return true;
 	}
 
-	return FALSE;
+	return false;
 }
 
-static connman_bool_t is_connecting(enum connman_service_state state)
+static bool is_connecting(enum connman_service_state state)
 {
 	switch (state) {
 	case CONNMAN_SERVICE_STATE_UNKNOWN:
@@ -1192,7 +1190,7 @@ static connman_bool_t is_connecting(enum connman_service_state state)
 		break;
 	case CONNMAN_SERVICE_STATE_ASSOCIATION:
 	case CONNMAN_SERVICE_STATE_CONFIGURATION:
-		return TRUE;
+		return true;
 	case CONNMAN_SERVICE_STATE_DISCONNECT:
 	case CONNMAN_SERVICE_STATE_FAILURE:
 	case CONNMAN_SERVICE_STATE_READY:
@@ -1200,47 +1198,47 @@ static connman_bool_t is_connecting(enum connman_service_state state)
 		break;
 	}
 
-	return FALSE;
+	return false;
 }
 
-static connman_bool_t explicit_connect(enum connman_session_reason reason)
+static bool explicit_connect(enum connman_session_reason reason)
 {
 	switch (reason) {
 	case CONNMAN_SESSION_REASON_UNKNOWN:
 	case CONNMAN_SESSION_REASON_FREE_RIDE:
 		break;
 	case CONNMAN_SESSION_REASON_CONNECT:
-		return TRUE;
+		return true;
 	}
 
-	return FALSE;
+	return false;
 }
 
-static connman_bool_t explicit_disconnect(struct session_info *info)
+static bool explicit_disconnect(struct session_info *info)
 {
-	if (info->entry == NULL)
-		return FALSE;
+	if (!info->entry)
+		return false;
 
 	DBG("reason %s service %p state %d",
 		reason2string(info->entry->reason),
 		info->entry->service, info->entry->state);
 
 	if (info->entry->reason == CONNMAN_SESSION_REASON_UNKNOWN)
-		return FALSE;
+		return false;
 
-	if (explicit_connect(info->entry->reason) == FALSE)
-		return FALSE;
+	if (!explicit_connect(info->entry->reason))
+		return false;
 
-	if (__connman_service_session_dec(info->entry->service) == FALSE)
-		return FALSE;
+	if (!__connman_service_session_dec(info->entry->service))
+		return false;
 
-	return TRUE;
+	return true;
 }
 
 struct pending_data {
 	unsigned int timeout;
 	struct service_entry *entry;
-	gboolean (*cb)(gpointer);
+	GSourceFunc cb;
 };
 
 static void pending_timeout_free(gpointer data, gpointer user_data)
@@ -1265,12 +1263,12 @@ static gboolean pending_timeout_cb(gpointer data)
 {
 	struct pending_data *pending = data;
 	struct service_entry *entry = pending->entry;
-	gboolean ret;
+	bool ret;
 
 	DBG("pending %p timeout %d", pending, pending->timeout);
 
 	ret = pending->cb(pending->entry);
-	if (ret == FALSE) {
+	if (!ret) {
 		entry->pending_timeouts =
 			g_slist_remove(entry->pending_timeouts,
 					pending);
@@ -1279,15 +1277,15 @@ static gboolean pending_timeout_cb(gpointer data)
 	return ret;
 }
 
-static connman_bool_t pending_timeout_add(unsigned int seconds,
-					gboolean (*cb)(gpointer),
+static bool pending_timeout_add(unsigned int seconds,
+					GSourceFunc cb,
 					struct service_entry *entry)
 {
 	struct pending_data *pending = g_try_new0(struct pending_data, 1);
 
-	if (pending == NULL || cb == NULL || entry == NULL) {
+	if (!pending || !cb || !entry) {
 		g_free(pending);
-		return FALSE;
+		return false;
 	}
 
 	pending->cb = cb;
@@ -1300,7 +1298,7 @@ static connman_bool_t pending_timeout_add(unsigned int seconds,
 	DBG("pending %p entry %p timeout id %d", pending, entry,
 		pending->timeout);
 
-	return TRUE;
+	return true;
 }
 
 static gboolean call_disconnect(gpointer user_data)
@@ -1333,17 +1331,17 @@ static gboolean call_connect(gpointer user_data)
 static void deselect_service(struct session_info *info)
 {
 	struct service_entry *entry;
-	connman_bool_t disconnect, connected;
+	bool disconnect, connected;
 
 	DBG("");
 
-	if (info->entry == NULL)
+	if (!info->entry)
 		return;
 
 	disconnect = explicit_disconnect(info);
 
-	connected = is_connecting(info->entry->state) == TRUE ||
-			is_connected(info->entry->state) == TRUE;
+	connected = is_connecting(info->entry->state) ||
+			is_connected(info->entry->state);
 
 	info->state = CONNMAN_SESSION_STATE_DISCONNECTED;
 	info->entry->reason = CONNMAN_SESSION_REASON_UNKNOWN;
@@ -1353,7 +1351,7 @@ static void deselect_service(struct session_info *info)
 
 	DBG("disconnect %d connected %d", disconnect, connected);
 
-	if (disconnect == TRUE && connected == TRUE)
+	if (disconnect && connected)
 		pending_timeout_add(0, call_disconnect, entry);
 }
 
@@ -1374,7 +1372,7 @@ static void select_connected_service(struct session_info *info,
 	enum connman_session_state state;
 
 	state = service_to_session_state(entry->state);
-	if (is_type_matching_state(&state, info->config.type) == FALSE)
+	if (!is_type_matching_state(&state, info->config.type))
 		return;
 
 	info->state = state;
@@ -1382,7 +1380,7 @@ static void select_connected_service(struct session_info *info,
 	info->entry = entry;
 	info->entry->reason = info->reason;
 
-	if (explicit_connect(info->reason) == FALSE)
+	if (!explicit_connect(info->reason))
 		return;
 
 	__connman_service_session_inc(info->entry->service);
@@ -1391,7 +1389,7 @@ static void select_connected_service(struct session_info *info,
 static void select_offline_service(struct session_info *info,
 					struct service_entry *entry)
 {
-	if (explicit_connect(info->reason) == FALSE)
+	if (!explicit_connect(info->reason))
 		return;
 
 	info->state = service_to_session_state(entry->state);
@@ -1408,7 +1406,7 @@ static void select_service(struct session_info *info,
 {
 	DBG("service %p", entry->service);
 
-	if (is_connected(entry->state) == TRUE)
+	if (is_connected(entry->state))
 		select_connected_service(info, entry);
 	else
 		select_offline_service(info, entry);
@@ -1427,7 +1425,7 @@ static void select_and_connect(struct connman_session *session,
 
 	info->reason = reason;
 
-	for (list = session->service_list; list != NULL; list = list->next) {
+	for (list = session->service_list; list; list = list->next) {
 		entry = list->data;
 
 		switch (entry->state) {
@@ -1446,7 +1444,8 @@ static void select_and_connect(struct connman_session *session,
 	}
 }
 
-static struct service_entry *create_service_entry(struct connman_session * session,
+static struct service_entry *create_service_entry(
+					struct connman_session * session,
 					struct connman_service *service,
 					const char *name,
 					enum connman_service_state state)
@@ -1456,12 +1455,12 @@ static struct service_entry *create_service_entry(struct connman_session * sessi
 	int idx;
 
 	entry = g_try_new0(struct service_entry, 1);
-	if (entry == NULL)
+	if (!entry)
 		return entry;
 
 	entry->reason = CONNMAN_SESSION_REASON_UNKNOWN;
 	entry->state = state;
-	if (name != NULL)
+	if (name)
 		entry->name = name;
 	else
 		entry->name = "";
@@ -1469,7 +1468,7 @@ static struct service_entry *create_service_entry(struct connman_session * sessi
 
 	idx = __connman_service_get_index(entry->service);
 	entry->ifname = connman_inet_ifname(idx);
-	if (entry->ifname == NULL)
+	if (!entry->ifname)
 		entry->ifname = g_strdup("");
 
 	type = connman_service_get_type(entry->service);
@@ -1488,11 +1487,11 @@ static void iterate_service_cb(struct connman_service *service,
 	struct connman_session *session = user_data;
 	struct service_entry *entry;
 
-	if (service_match(session, service) == FALSE)
+	if (!service_match(session, service))
 		return;
 
 	entry = create_service_entry(session, service, name, state);
-	if (entry == NULL)
+	if (!entry)
 		return;
 
 	g_hash_table_replace(session->service_hash, service, entry);
@@ -1504,7 +1503,7 @@ static void destroy_service_entry(gpointer data)
 	struct session_info *info = entry->session->info;
 	struct connman_session *session;
 
-	if (info != NULL && info->entry == entry) {
+	if (info && info->entry == entry) {
 		session = entry->session;
 		deselect_and_disconnect(session);
 	}
@@ -1527,7 +1526,7 @@ static void populate_service_list(struct connman_session *session)
 
 	g_hash_table_iter_init(&iter, session->service_hash);
 
-	while (g_hash_table_iter_next(&iter, &key, &value) == TRUE) {
+	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		struct service_entry *entry = value;
 
 		DBG("service %p type %s name %s", entry->service,
@@ -1558,12 +1557,12 @@ static void session_changed(struct connman_session *session,
 	DBG("session %p trigger %s reason %s", session, trigger2string(trigger),
 						reason2string(info->reason));
 
-	if (info->entry != NULL) {
+	if (info->entry) {
 		enum connman_session_state state;
 
 		state = service_to_session_state(info->entry->state);
 
-		if (is_type_matching_state(&state, info->config.type) == TRUE)
+		if (is_type_matching_state(&state, info->config.type))
 			info->state = state;
 	}
 
@@ -1578,14 +1577,14 @@ static void session_changed(struct connman_session *session,
 			g_list_free(session->service_list);
 			session->service_list = NULL;
 
-			if (info->entry != NULL)
+			if (info->entry)
 				service = info->entry->service;
 			else
 				service = NULL;
 
 			populate_service_list(session);
 
-			if (info->entry != NULL) {
+			if (info->entry) {
 				entry_last = g_hash_table_lookup(
 							service_hash_last,
 							info->entry->service);
@@ -1594,7 +1593,7 @@ static void session_changed(struct connman_session *session,
 							service);
 			}
 
-			if (entry == NULL && entry_last != NULL) {
+			if (!entry && entry_last) {
 				/*
 				 * The currently selected service is
 				 * not part of this session anymore.
@@ -1607,8 +1606,8 @@ static void session_changed(struct connman_session *session,
 
 		if (info->config.type != info_last->config.type) {
 			if (info->state >= CONNMAN_SESSION_STATE_CONNECTED &&
-					is_type_matching_state(&info->state,
-							info->config.type) == FALSE)
+					!is_type_matching_state(&info->state,
+							info->config.type))
 				deselect_and_disconnect(session);
 		}
 
@@ -1632,8 +1631,8 @@ static void session_changed(struct connman_session *session,
 			break;
 		}
 
-		if (info->entry != NULL &&
-				is_connecting(info->entry->state) == TRUE) {
+		if (info->entry &&
+				is_connecting(info->entry->state)) {
 			break;
 		}
 
@@ -1646,17 +1645,15 @@ static void session_changed(struct connman_session *session,
 
 		break;
 	case CONNMAN_SESSION_TRIGGER_SERVICE:
-		if (info->entry != NULL &&
-			(is_connecting(info->entry->state) == TRUE ||
-				is_connected(info->entry->state) == TRUE)) {
+		if (info->entry &&
+			(is_connecting(info->entry->state) ||
+				is_connected(info->entry->state)))
 			break;
-		}
 
 		deselect_and_disconnect(session);
 
-		if (info->reason == CONNMAN_SESSION_REASON_FREE_RIDE) {
+		if (info->reason == CONNMAN_SESSION_REASON_FREE_RIDE)
 			select_and_connect(session, info->reason);
-		}
 
 		break;
 	}
@@ -1705,7 +1702,7 @@ int connman_session_config_update(struct connman_session *session)
 	info->config.roaming_policy = session->policy_config->roaming_policy;
 
 	info->config.ecall = session->policy_config->ecall;
-	if (info->config.ecall == TRUE)
+	if (info->config.ecall)
 		ecall_session = session;
 
 	info->config.priority = session->policy_config->priority;
@@ -1722,11 +1719,11 @@ static DBusMessage *connect_session(DBusConnection *conn,
 
 	DBG("session %p", session);
 
-	if (ecall_session != NULL) {
-		if (ecall_session->ecall == TRUE && ecall_session != session)
+	if (ecall_session) {
+		if (ecall_session->ecall && ecall_session != session)
 			return __connman_error_failed(msg, EBUSY);
 
-		session->ecall = TRUE;
+		session->ecall = true;
 		session_changed(session, CONNMAN_SESSION_TRIGGER_ECALL);
 	} else
 		session_changed(session, CONNMAN_SESSION_TRIGGER_CONNECT);
@@ -1741,11 +1738,11 @@ static DBusMessage *disconnect_session(DBusConnection *conn,
 
 	DBG("session %p", session);
 
-	if (ecall_session != NULL) {
-		if (ecall_session->ecall == TRUE && ecall_session != session)
+	if (ecall_session) {
+		if (ecall_session->ecall && ecall_session != session)
 			return __connman_error_failed(msg, EBUSY);
 
-		session->ecall = FALSE;
+		session->ecall = false;
 	}
 
 	session_changed(session, CONNMAN_SESSION_TRIGGER_DISCONNECT);
@@ -1765,7 +1762,7 @@ static DBusMessage *change_session(DBusConnection *conn,
 	int err;
 
 	DBG("session %p", session);
-	if (dbus_message_iter_init(msg, &iter) == FALSE)
+	if (!dbus_message_iter_init(msg, &iter))
 		return __connman_error_invalid_arguments(msg);
 
 	if (dbus_message_iter_get_arg_type(&iter) != DBUS_TYPE_STRING)
@@ -1781,10 +1778,10 @@ static DBusMessage *change_session(DBusConnection *conn,
 
 	switch (dbus_message_iter_get_arg_type(&value)) {
 	case DBUS_TYPE_ARRAY:
-		if (g_str_equal(name, "AllowedBearers") == TRUE) {
+		if (g_str_equal(name, "AllowedBearers")) {
 			err = parse_bearers(&value, &allowed_bearers);
 			if (err < 0)
-				return __connman_error_failed(msg, err);
+				return __connman_error_failed(msg, -err);
 
 			g_slist_free(info->config.allowed_bearers);
 			session->user_allowed_bearers = allowed_bearers;
@@ -1795,13 +1792,13 @@ static DBusMessage *change_session(DBusConnection *conn,
 					&info->config.allowed_bearers);
 
 			if (err < 0)
-				return __connman_error_failed(msg, err);
+				return __connman_error_failed(msg, -err);
 		} else {
 			goto err;
 		}
 		break;
 	case DBUS_TYPE_STRING:
-		if (g_str_equal(name, "ConnectionType") == TRUE) {
+		if (g_str_equal(name, "ConnectionType")) {
 			dbus_message_iter_get_basic(&value, &val);
 			info->config.type = apply_policy_on_type(
 				session->policy_config->type,
@@ -1839,7 +1836,7 @@ static void release_session(gpointer key, gpointer value, gpointer user_data)
 						session->notify_path,
 						CONNMAN_NOTIFICATION_INTERFACE,
 						"Release");
-	if (message == NULL)
+	if (!message)
 		return;
 
 	dbus_message_set_no_reply(message, TRUE);
@@ -1880,7 +1877,7 @@ static DBusMessage *destroy_session(DBusConnection *conn,
 
 	DBG("session %p", session);
 
-	if (ecall_session != NULL && ecall_session != session)
+	if (ecall_session && ecall_session != session)
 		return __connman_error_failed(msg, EBUSY);
 
 	session_disconnect(session);
@@ -1922,7 +1919,7 @@ static int session_create_final(struct creation_data *creation_data,
 	info = session->info;
 	info_last = session->info_last;
 
-	if (session->policy_config->ecall == TRUE)
+	if (session->policy_config->ecall)
 		ecall_session = session;
 
 	info->state = CONNMAN_SESSION_STATE_DISCONNECTED;
@@ -1947,10 +1944,10 @@ static int session_create_final(struct creation_data *creation_data,
 
 	DBG("add %s", session->session_path);
 
-	if (g_dbus_register_interface(connection, session->session_path,
+	if (!g_dbus_register_interface(connection, session->session_path,
 					CONNMAN_SESSION_INTERFACE,
-					session_methods, NULL,
-					NULL, session, NULL) == FALSE) {
+					session_methods, NULL, NULL,
+					session, NULL)) {
 		connman_error("Failed to register %s", session->session_path);
 		g_hash_table_remove(session_hash, session->session_path);
 		err = -EINVAL;
@@ -1971,7 +1968,7 @@ static int session_create_final(struct creation_data *creation_data,
 	info_last->entry = info->entry;
 	info_last->config.allowed_bearers = info->config.allowed_bearers;
 
-	session->append_all = TRUE;
+	session->append_all = true;
 
 	session_changed(session, CONNMAN_SESSION_TRIGGER_SETTING);
 
@@ -2039,7 +2036,7 @@ static int session_policy_config_cb(struct connman_session *session,
 	session->index = -1;
 
 	session->nfctx = __connman_nfacct_create_context();
-	if (session->nfctx == NULL) {
+	if (!session->nfctx) {
 		err = -ENOMEM;
 		goto err;
 	}
@@ -2086,15 +2083,16 @@ int __connman_session_create(DBusMessage *msg)
 	DBusMessageIter iter, array;
 	struct connman_session *session = NULL;
 	struct creation_data *creation_data = NULL;
-	connman_bool_t user_allowed_bearers = FALSE;
-	connman_bool_t user_connection_type = FALSE;
-	int err;
+	bool user_allowed_bearers = false;
+	bool user_connection_type = false;
+	int err, i;
+	char *str;
 
 	owner = dbus_message_get_sender(msg);
 
 	DBG("owner %s", owner);
 
-	if (ecall_session != NULL && ecall_session->ecall == TRUE) {
+	if (ecall_session && ecall_session->ecall) {
 		/*
 		 * If there is an emergency call already going on,
 		 * ignore session creation attempt
@@ -2104,7 +2102,7 @@ int __connman_session_create(DBusMessage *msg)
 	}
 
 	creation_data = g_try_new0(struct creation_data, 1);
-	if (creation_data == NULL) {
+	if (!creation_data) {
 		err = -ENOMEM;
 		goto err;
 	}
@@ -2126,25 +2124,25 @@ int __connman_session_create(DBusMessage *msg)
 
 		switch (dbus_message_iter_get_arg_type(&value)) {
 		case DBUS_TYPE_ARRAY:
-			if (g_str_equal(key, "AllowedBearers") == TRUE) {
+			if (g_str_equal(key, "AllowedBearers")) {
 				err = parse_bearers(&value,
-						&creation_data->allowed_bearers);
+					&creation_data->allowed_bearers);
 				if (err < 0)
 					goto err;
 
-				user_allowed_bearers = TRUE;
+				user_allowed_bearers = true;
 			} else {
 				err = -EINVAL;
 				goto err;
 			}
 			break;
 		case DBUS_TYPE_STRING:
-			if (g_str_equal(key, "ConnectionType") == TRUE) {
+			if (g_str_equal(key, "ConnectionType")) {
 				dbus_message_iter_get_basic(&value, &val);
 				creation_data->type =
 					connman_session_parse_connection_type(val);
 
-				user_connection_type = TRUE;
+				user_connection_type = true;
 			} else {
 				err = -EINVAL;
 				goto err;
@@ -2159,36 +2157,42 @@ int __connman_session_create(DBusMessage *msg)
 	 *
 	 * For AllowedBearers this is '*', ...
 	 */
-	if (user_allowed_bearers == FALSE) {
+	if (!user_allowed_bearers) {
 		creation_data->allowed_bearers =
 			g_slist_append(NULL,
 				GINT_TO_POINTER(CONNMAN_SERVICE_TYPE_UNKNOWN));
-		if (creation_data->allowed_bearers == NULL) {
+		if (!creation_data->allowed_bearers) {
 			err = -ENOMEM;
 			goto err;
 		}
 	}
 
 	/* ... and for ConnectionType it is 'any'. */
-	if (user_connection_type == FALSE)
+	if (!user_connection_type)
 		creation_data->type = CONNMAN_SESSION_TYPE_ANY;
 
 	dbus_message_iter_next(&iter);
 	dbus_message_iter_get_basic(&iter, &notify_path);
 
-	if (notify_path == NULL) {
+	if (!notify_path) {
 		err = -EINVAL;
 		goto err;
 	}
 
-	session_path = g_strdup_printf("/sessions%s", notify_path);
-	if (session_path == NULL) {
+	str = g_strdup(owner);
+	for (i = 0; str[i] != '\0'; i++)
+		if (str[i] == ':' || str[i] == '.')
+			str[i] = '_';
+	session_path = g_strdup_printf("/sessions/%s%s", str, notify_path);
+	g_free(str);
+
+	if (!session_path) {
 		err = -ENOMEM;
 		goto err;
 	}
 
 	session = g_hash_table_lookup(session_hash, session_path);
-	if (session != NULL) {
+	if (session) {
 		g_free(session_path);
 		session = NULL;
 		err = -EEXIST;
@@ -2196,7 +2200,7 @@ int __connman_session_create(DBusMessage *msg)
 	}
 
 	session = g_try_new0(struct connman_session, 1);
-	if (session == NULL) {
+	if (!session) {
 		g_free(session_path);
 		err = -ENOMEM;
 		goto err;
@@ -2206,13 +2210,13 @@ int __connman_session_create(DBusMessage *msg)
 	session->session_path = session_path;
 
 	session->info = g_try_new0(struct session_info, 1);
-	if (session->info == NULL) {
+	if (!session->info) {
 		err = -ENOMEM;
 		goto err;
 	}
 
 	session->info_last = g_try_new0(struct session_info, 1);
-	if (session->info_last == NULL) {
+	if (!session->info_last) {
 		err = -ENOMEM;
 		goto err;
 	}
@@ -2261,11 +2265,11 @@ int __connman_session_destroy(DBusMessage *msg)
 
 	dbus_message_get_args(msg, NULL, DBUS_TYPE_OBJECT_PATH, &session_path,
 							DBUS_TYPE_INVALID);
-	if (session_path == NULL)
+	if (!session_path)
 		return -EINVAL;
 
 	session = g_hash_table_lookup(session_hash, session_path);
-	if (session == NULL)
+	if (!session)
 		return -EINVAL;
 
 	if (g_strcmp0(owner, session->owner) != 0)
@@ -2276,24 +2280,27 @@ int __connman_session_destroy(DBusMessage *msg)
 	return 0;
 }
 
-connman_bool_t __connman_session_mode()
+bool __connman_session_mode()
 {
 	return sessionmode;
 }
 
-void __connman_session_set_mode(connman_bool_t enable)
+void __connman_session_set_mode(bool enable)
 {
+	dbus_bool_t mode;
+
 	DBG("enable %d", enable);
 
 	if (sessionmode != enable) {
 		sessionmode = enable;
 
+		mode = sessionmode;
 		connman_dbus_property_changed_basic(CONNMAN_MANAGER_PATH,
 				CONNMAN_MANAGER_INTERFACE, "SessionMode",
-				DBUS_TYPE_BOOLEAN, &sessionmode);
+				DBUS_TYPE_BOOLEAN, &mode);
 	}
 
-	if (sessionmode == TRUE)
+	if (sessionmode)
 		__connman_service_disconnect_all();
 }
 
@@ -2309,15 +2316,15 @@ static void service_add(struct connman_service *service,
 
 	g_hash_table_iter_init(&iter, session_hash);
 
-	while (g_hash_table_iter_next(&iter, &key, &value) == TRUE) {
+	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		session = value;
 
-		if (service_match(session, service) == FALSE)
+		if (!service_match(session, service))
 			continue;
 
 		entry = create_service_entry(session, service, name,
 						CONNMAN_SERVICE_STATE_IDLE);
-		if (entry == NULL)
+		if (!entry)
 			continue;
 
 		session->service_list = g_list_insert_sorted_with_data(
@@ -2341,13 +2348,13 @@ static void service_remove(struct connman_service *service)
 
 	g_hash_table_iter_init(&iter, session_hash);
 
-	while (g_hash_table_iter_next(&iter, &key, &value) == TRUE) {
+	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		struct service_entry *entry;
 		session = value;
 		info = session->info;
 
 		entry = g_hash_table_lookup(session->service_hash, service);
-		if (entry == NULL)
+		if (!entry)
 			continue;
 
 		session->service_list = g_list_remove(session->service_list,
@@ -2355,7 +2362,7 @@ static void service_remove(struct connman_service *service)
 
 		g_hash_table_remove(session->service_hash, service);
 
-		if (info->entry != NULL && info->entry->service == service)
+		if (info->entry && info->entry->service == service)
 			info->entry = NULL;
 		session_changed(session, CONNMAN_SESSION_TRIGGER_SERVICE);
 	}
@@ -2371,12 +2378,12 @@ static void service_state_changed(struct connman_service *service,
 
 	g_hash_table_iter_init(&iter, session_hash);
 
-	while (g_hash_table_iter_next(&iter, &key, &value) == TRUE) {
+	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		struct connman_session *session = value;
 		struct service_entry *entry;
 
 		entry = g_hash_table_lookup(session->service_hash, service);
-		if (entry != NULL)
+		if (entry)
 			entry->state = state;
 
 		session_changed(session,
@@ -2399,14 +2406,14 @@ static void ipconfig_changed(struct connman_service *service,
 
 	g_hash_table_iter_init(&iter, session_hash);
 
-	while (g_hash_table_iter_next(&iter, &key, &value) == TRUE) {
+	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		session = value;
 		info = session->info;
 
 		if (info->state == CONNMAN_SESSION_STATE_DISCONNECTED)
 			continue;
 
-		if (info->entry != NULL && info->entry->service == service) {
+		if (info->entry && info->entry->service == service) {
 			if (type == CONNMAN_IPCONFIG_TYPE_IPV4)
 				ipconfig_ipv4_changed(session);
 			else if (type == CONNMAN_IPCONFIG_TYPE_IPV6)
@@ -2444,7 +2451,7 @@ int __connman_session_init(void)
 		return err;
 
 	connection = connman_dbus_get_connection();
-	if (connection == NULL)
+	if (!connection)
 		return -1;
 
 	err = connman_notifier_register(&session_notifier);
@@ -2457,7 +2464,7 @@ int __connman_session_init(void)
 	session_hash = g_hash_table_new_full(g_str_hash, g_str_equal,
 						NULL, cleanup_session);
 
-	sessionmode = FALSE;
+	sessionmode = false;
 
 	__connman_nfacct_flush(session_nfacct_flush_cb, NULL);
 
@@ -2468,7 +2475,7 @@ void __connman_session_cleanup(void)
 {
 	DBG("");
 
-	if (connection == NULL)
+	if (!connection)
 		return;
 
 	cleanup_firewall();
